import type { TlsConfig } from '@stacksjs/tlsx';

export type { TlsConfig };
export declare type CustomTlsConfig = Partial<Omit<TlsConfig, 'caCertPath' | 'certPath' | 'keyPath'>> &
  Pick<TlsConfig, 'caCertPath' | 'certPath' | 'keyPath'>
export declare interface BaseReverseProxyConfig {
  from: string 
  to: string 
}
export declare interface CleanupOptions {
  domains?: string[]
  etcHostsCleanup?: boolean
  verbose?: boolean
}
export declare interface SharedProxySettings {
  https: boolean | CustomTlsConfig
  etcHostsCleanup: boolean
  verbose: boolean
  _cachedSSLConfig?: SSLConfig | null
}
export declare interface SingleReverseProxyConfig extends BaseReverseProxyConfig, SharedProxySettings {}
export declare interface MultiReverseProxyConfig extends SharedProxySettings {
  proxies: BaseReverseProxyConfig[]
}
export declare type ReverseProxyConfigs = SingleReverseProxyConfig | MultiReverseProxyConfig
export declare type BaseReverseProxyOption = Partial<BaseReverseProxyConfig>
export type PartialSharedSettings = Partial<SharedProxySettings>
export declare type MultiReverseProxyOption = MultiReverseProxyConfig
export declare type ReverseProxyOption = SingleReverseProxyConfig
export type ReverseProxyOptions = SingleReverseProxyConfig | MultiReverseProxyOption
export declare interface SSLConfig {
  key: string
  cert: string
  ca?: string | string[]
}
export declare interface ProxySetupOptions extends Omit<ReverseProxyOption, 'from'> {
  fromPort: number
  sourceUrl: Pick<URL, 'hostname' | 'host'>
  ssl: SSLConfig | null
  from: string
  to: string
}
export declare interface PortManager {
  usedPorts: Set<number>
  getNextAvailablePort: (startPort: number) => Promise<number>
}
export declare interface ProxySetupOptions extends Omit<ReverseProxyOption, 'from'> {
  fromPort: number
  sourceUrl: Pick<URL, 'hostname' | 'host'>
  ssl: SSLConfig | null
  from: string
  to: string
  portManager?: PortManager
}